/*------------------------------------------------------------------------------
    GALE. Fine-grained parallel Genetic Algorithms for Data Mining.
    Copyright (C) 2002  Xavier Llor <xllora@illigal.ge.uiuc.edu>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
------------------------------------------------------------------------------*/


package edu.uiuc.ge.illigal.gale.data;

import java.util.Vector;
import java.util.Random;

/**
 * This class is a folder view for cross-validation over a certain set
 *
 * @author  Xavier Llor&agrave; &lt;<a href="mailto:xllora@illigal.ge.uiuc.edu">xllora@illigal.ge.uiuc.edu</a>&gt;
 * @version 0.9alpha
 * @since 0.9alpha
 */

public class FoldView 
implements OrderedSet
{
   //---------------------------------------------------------------------

	/** The array of instances */
	private Instance [] insa;

	/** The number of instances in the view */
	private int iSize;

   //---------------------------------------------------------------------

	/** Builds a view over the vector given.
	 *
    * @param vec The ordered set that contains the data	
    * @param rnd The random number generator
    */
   public FoldView ( Vector vec, Random rnd )
   {
		int    i = 0;
		int iTmp = -1;

		iSize = vec.size();
		insa  = new Instance[iSize];

		while ( vec.size()>0 ) {
			iTmp = rnd.nextInt(vec.size());
			insa[i] = (Instance)vec.elementAt(iTmp); 
			vec.removeElementAt(iTmp);
			i++;
		}
   }

   //---------------------------------------------------------------------

	// OrderedSet implementation
   public Instance getInstance ( int iPos )
	{
		return insa[iPos];
	}

   //---------------------------------------------------------------------

   // OrderedSet implementation
	public int getSize ()
   {
		return iSize;
	}

   //---------------------------------------------------------------------
}
